==> pde-2.25.0.tgz: package/lib/adapters/optimizely/multiple.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _classPrivateFieldLooseBase from "@babel/runtime/helpers/esm/classPrivateFieldLooseBase";
import _classPrivateFieldLooseKey from "@babel/runtime/helpers/esm/classPrivateFieldLooseKey";
var _excluded = ["datafile", "sdkKey"],
  _excluded2 = ["adapterId"],
  _excluded3 = ["adapterId"],
  _excluded4 = ["adapterId"],
  _excluded5 = ["adapterId"],
  _excluded6 = ["adapterId"],
  _excluded7 = ["adapterId"];
import OptimizelyAdapter from './index.js';
var defaultAdapterId;
var _adapters = /*#__PURE__*/_classPrivateFieldLooseKey("adapters");
var MultipleOptimizelyAdapter = /*#__PURE__*/function () {
  function MultipleOptimizelyAdapter(optimizelyAdapters) {
    Object.defineProperty(this, _adapters, {
      writable: true,
      value: {}
    });
    defaultAdapterId = Object.keys(optimizelyAdapters)[0]; // first adapter will be the defaultAdapter

    _classPrivateFieldLooseBase(this, _adapters)[_adapters] = Object.keys(optimizelyAdapters).reduce(function (acc, adapterId) {
      acc[adapterId] = new OptimizelyAdapter(optimizelyAdapters[adapterId]);
      return acc;
    }, {});
  }
  MultipleOptimizelyAdapter.createMultipleOptimizelyInstances = function createMultipleOptimizelyInstances(optionsByInstance) {
    return Object.keys(optionsByInstance).reduce(function (acc, adapterId) {
      var _window$__INITIAL_CON;
      var _optionsByInstance$ad = optionsByInstance[adapterId],
        datafile = _optionsByInstance$ad.datafile,
        sdkKey = _optionsByInstance$ad.sdkKey,
        restOptions = _objectWithoutPropertiesLoose(_optionsByInstance$ad, _excluded);
      if (!datafile && typeof window !== 'undefined' && (_window$__INITIAL_CON = window.__INITIAL_CONTEXT_VALUE__) != null && _window$__INITIAL_CON.pde[adapterId]) {
        datafile = window.__INITIAL_CONTEXT_VALUE__.pde[adapterId];
        sdkKey = undefined;
      }
      acc[adapterId] = OptimizelyAdapter.createOptimizelyInstance(_extends({
        datafile: datafile,
        sdkKey: sdkKey
      }, restOptions));
      return acc;
    }, {});
  };
  var _proto = MultipleOptimizelyAdapter.prototype;
  _proto.getInitialData = function getInitialData() {
    var _this = this;
    var initialData = {};
    Object.keys(_classPrivateFieldLooseBase(this, _adapters)[_adapters]).forEach(function (adapterId) {
      var adapter = _classPrivateFieldLooseBase(_this, _adapters)[_adapters][adapterId];
      initialData[adapterId] = adapter.getInitialData();
    });
    return initialData;
  };
  _proto.onReady = function onReady() {
    return Promise.all(Object.values(_classPrivateFieldLooseBase(this, _adapters)[_adapters]).map(function (adapter) {
      return adapter.onReady();
    }));
  };
  _proto.getEnabledFeatures = function getEnabledFeatures(_ref) {
    var _ref$adapterId = _ref.adapterId,
      adapterId = _ref$adapterId === void 0 ? defaultAdapterId : _ref$adapterId,
      props = _objectWithoutPropertiesLoose(_ref, _excluded2);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].getEnabledFeatures(props);
  };
  _proto.getOptimizelyConfig = function getOptimizelyConfig(_ref2) {
    var _ref2$adapterId = _ref2.adapterId,
      adapterId = _ref2$adapterId === void 0 ? defaultAdapterId : _ref2$adapterId,
      props = _objectWithoutPropertiesLoose(_ref2, _excluded3);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].getOptimizelyConfig(props);
  };
  _proto.activateExperiment = function activateExperiment(_ref3) {
    var _ref3$adapterId = _ref3.adapterId,
      adapterId = _ref3$adapterId === void 0 ? defaultAdapterId : _ref3$adapterId,
      props = _objectWithoutPropertiesLoose(_ref3, _excluded4);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].activateExperiment(props);
  };
  _proto.getVariation = function getVariation(_ref4) {
    var _ref4$adapterId = _ref4.adapterId,
      adapterId = _ref4$adapterId === void 0 ? defaultAdapterId : _ref4$adapterId,
      props = _objectWithoutPropertiesLoose(_ref4, _excluded5);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].getVariation(props);
  };
  _proto.isFeatureEnabled = function isFeatureEnabled(_ref5) {
    var _ref5$adapterId = _ref5.adapterId,
      adapterId = _ref5$adapterId === void 0 ? defaultAdapterId : _ref5$adapterId,
      props = _objectWithoutPropertiesLoose(_ref5, _excluded6);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].isFeatureEnabled(props);
  };
  _proto.getAllFeatureVariables = function getAllFeatureVariables(_ref6) {
    var _ref6$adapterId = _ref6.adapterId,
      adapterId = _ref6$adapterId === void 0 ? defaultAdapterId : _ref6$adapterId,
      props = _objectWithoutPropertiesLoose(_ref6, _excluded7);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].getAllFeatureVariables(props);
  };
  _proto.updateConsents = function updateConsents(props) {
    var _this2 = this;
    Object.keys(_classPrivateFieldLooseBase(this, _adapters)[_adapters]).forEach(function (adapterId) {
      var adapter = _classPrivateFieldLooseBase(_this2, _adapters)[_adapters][adapterId];
      adapter.updateConsents(props);
    });
  };
  return MultipleOptimizelyAdapter;
}();
export default MultipleOptimizelyAdapter;

==> pde-2.26.0.tgz: package/lib/adapters/optimizely/multiple.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _classPrivateFieldLooseBase from "@babel/runtime/helpers/esm/classPrivateFieldLooseBase";
import _classPrivateFieldLooseKey from "@babel/runtime/helpers/esm/classPrivateFieldLooseKey";
var _excluded = ["datafile", "sdkKey"],
  _excluded2 = ["adapterId"],
  _excluded3 = ["adapterId"],
  _excluded4 = ["adapterId"],
  _excluded5 = ["adapterId"],
  _excluded6 = ["adapterId"],
  _excluded7 = ["adapterId"],
  _excluded8 = ["adapterId"];
import OptimizelyAdapter from './index.js';
var defaultAdapterId;
var _adapters = /*#__PURE__*/_classPrivateFieldLooseKey("adapters");
var MultipleOptimizelyAdapter = /*#__PURE__*/function () {
  function MultipleOptimizelyAdapter(optimizelyAdapters) {
    Object.defineProperty(this, _adapters, {
      writable: true,
      value: {}
    });
    defaultAdapterId = Object.keys(optimizelyAdapters)[0]; // first adapter will be the defaultAdapter

    _classPrivateFieldLooseBase(this, _adapters)[_adapters] = Object.keys(optimizelyAdapters).reduce(function (acc, adapterId) {
      acc[adapterId] = new OptimizelyAdapter(optimizelyAdapters[adapterId]);
      return acc;
    }, {});
  }
  MultipleOptimizelyAdapter.createMultipleOptimizelyInstances = function createMultipleOptimizelyInstances(optionsByInstance) {
    return Object.keys(optionsByInstance).reduce(function (acc, adapterId) {
      var _window$__INITIAL_CON;
      var _optionsByInstance$ad = optionsByInstance[adapterId],
        datafile = _optionsByInstance$ad.datafile,
        sdkKey = _optionsByInstance$ad.sdkKey,
        restOptions = _objectWithoutPropertiesLoose(_optionsByInstance$ad, _excluded);
      if (!datafile && typeof window !== 'undefined' && (_window$__INITIAL_CON = window.__INITIAL_CONTEXT_VALUE__) != null && _window$__INITIAL_CON.pde[adapterId]) {
        datafile = window.__INITIAL_CONTEXT_VALUE__.pde[adapterId];
        sdkKey = undefined;
      }
      acc[adapterId] = OptimizelyAdapter.createOptimizelyInstance(_extends({
        datafile: datafile,
        sdkKey: sdkKey
      }, restOptions));
      return acc;
    }, {});
  };
  var _proto = MultipleOptimizelyAdapter.prototype;
  _proto.getInitialData = function getInitialData() {
    var _this = this;
    var initialData = {};
    Object.keys(_classPrivateFieldLooseBase(this, _adapters)[_adapters]).forEach(function (adapterId) {
      var adapter = _classPrivateFieldLooseBase(_this, _adapters)[_adapters][adapterId];
      initialData[adapterId] = adapter.getInitialData();
    });
    return initialData;
  };
  _proto.onReady = function onReady() {
    return Promise.all(Object.values(_classPrivateFieldLooseBase(this, _adapters)[_adapters]).map(function (adapter) {
      return adapter.onReady();
    }));
  };
  _proto.getEnabledFeatures = function getEnabledFeatures(_ref) {
    var _ref$adapterId = _ref.adapterId,
      adapterId = _ref$adapterId === void 0 ? defaultAdapterId : _ref$adapterId,
      props = _objectWithoutPropertiesLoose(_ref, _excluded2);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].getEnabledFeatures(props);
  };
  _proto.getOptimizelyConfig = function getOptimizelyConfig(_ref2) {
    var _ref2$adapterId = _ref2.adapterId,
      adapterId = _ref2$adapterId === void 0 ? defaultAdapterId : _ref2$adapterId,
      props = _objectWithoutPropertiesLoose(_ref2, _excluded3);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].getOptimizelyConfig(props);
  };
  _proto.activateExperiment = function activateExperiment(_ref3) {
    var _ref3$adapterId = _ref3.adapterId,
      adapterId = _ref3$adapterId === void 0 ? defaultAdapterId : _ref3$adapterId,
      props = _objectWithoutPropertiesLoose(_ref3, _excluded4);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].activateExperiment(props);
  };
  _proto.decide = function decide(_ref4) {
    var _ref4$adapterId = _ref4.adapterId,
      adapterId = _ref4$adapterId === void 0 ? defaultAdapterId : _ref4$adapterId,
      props = _objectWithoutPropertiesLoose(_ref4, _excluded5);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].decide(props);
  };
  _proto.getVariation = function getVariation(_ref5) {
    var _ref5$adapterId = _ref5.adapterId,
      adapterId = _ref5$adapterId === void 0 ? defaultAdapterId : _ref5$adapterId,
      props = _objectWithoutPropertiesLoose(_ref5, _excluded6);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].getVariation(props);
  };
  _proto.isFeatureEnabled = function isFeatureEnabled(_ref6) {
    var _ref6$adapterId = _ref6.adapterId,
      adapterId = _ref6$adapterId === void 0 ? defaultAdapterId : _ref6$adapterId,
      props = _objectWithoutPropertiesLoose(_ref6, _excluded7);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].isFeatureEnabled(props);
  };
  _proto.getAllFeatureVariables = function getAllFeatureVariables(_ref7) {
    var _ref7$adapterId = _ref7.adapterId,
      adapterId = _ref7$adapterId === void 0 ? defaultAdapterId : _ref7$adapterId,
      props = _objectWithoutPropertiesLoose(_ref7, _excluded8);
    return _classPrivateFieldLooseBase(this, _adapters)[_adapters][adapterId].getAllFeatureVariables(props);
  };
  _proto.updateConsents = function updateConsents(props) {
    var _this2 = this;
    Object.keys(_classPrivateFieldLooseBase(this, _adapters)[_adapters]).forEach(function (adapterId) {
      var adapter = _classPrivateFieldLooseBase(_this2, _adapters)[_adapters][adapterId];
      adapter.updateConsents(props);
    });
  };
  return MultipleOptimizelyAdapter;
}();
export default MultipleOptimizelyAdapter;
